@@ -1,5 +1,6 @@
 import datetime
 import os
+import time
 
 import requests
 from lxml import etree, html
@@ -69,8 +70,7 @@ def get_page_urls(page_content, rows, url):
 
 def download_chart_image(page_content: requests.Response, **kwargs):
     """ Downloads a .png image of a chart into the "charts" folder. """
-
-    file_name = kwargs["URL"].split("t=")[1] + ".png"
+    file_name = f"{kwargs['URL'].split('t=')[1]}_{int(time.time())}.png"
 
     if not os.path.exists("charts"):
         os.mkdir("charts")
